@@ -13,9 +13,10 @@
 #
 #      You should have received a copy of the GNU General Public License
 #      along with this program.  If not, see <https://www.gnu.org/licenses/>.
-
+import errno
 import json
 import logging
+import os
 from datetime import datetime
 from typing import Dict
 
@@ -30,12 +31,18 @@ def get_schedule(provider: Provider, province: Province, suburb: Suburb, stage:
     stage_schedule = {}
     cached_schedule = {}
 
+    try:
+        os.makedirs('.cache')
+    except OSError as e:
+        if e.errno != errno.EEXIST:
+            raise
+
     if stage in [None, Stage.UNKNOWN]:
         try:
             stage = provider.get_stage()
         except ProviderError as e:
             logging.log(logging.ERROR, "Unable to get stage from {provider}. {e}".format(provider=provider, e=e))
-            raise e
+            raise
 
     if stage in [None, Stage.UNKNOWN, Stage.NO_LOAD_SHEDDING]:
         raise ScheduleError("{stage}".format(stage=Stage.NO_LOAD_SHEDDING))
@@ -60,7 +67,7 @@ def get_schedule(provider: Provider, province: Province, suburb: Suburb, stage:
         logging.log(logging.ERROR, "Unable to get schedule from {provider}. {e}".format(provider=provider, e=e))
         if cached_schedule:
             return cached_schedule
-        raise e
+        raise
 
     cache_file = ".cache/{suburb_id}.json".format(suburb_id=suburb.id)
     with open(cache_file, "w") as cache:
